package Alien::libextism;

use 5.016;
use strict;
use warnings;
use parent qw( Alien::Base );
use version 0.77;
our $VERSION = qv(v0.1.1);

1;

__END__

=pod

=encoding utf-8

=head1 NAME

Alien::libextism - find or build and install libextism with development
dependencies

=head1 SUPPORT AND DOCUMENTATION

You can find documentation for this module with the perldoc command.

    perldoc Alien::libextism

Additional documentation, support, and bug reports can be found at the
Extism perl-sdk repository L<https://github.com/extism/perl-sdk>

Additional Extism support may be found in the discord server:
L<https://extism.org/discord>

=head1 LICENSE AND COPYRIGHT

This software is copyright (c) 2024 by Dylibso.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
